@@ -1,5 +1,6 @@
 #ifndef __keyATM_base__INCLUDED__
 #define __keyATM_base__INCLUDED__
+#define EIGEN_PERMANENTLY_DISABLE_STUPID_WARNINGS
 
 #include <Rcpp.h>
 #include <RcppEigen.h>
@@ -13,7 +14,7 @@ using namespace std;
 
 class keyATMbase : virtual public keyATMmeta
 {
-  public:  
+  public:
     //
     // Parameters
     //
@@ -27,30 +28,28 @@ class keyATMbase : virtual public keyATMmeta
 
       // in alpha_loglik
       MatrixXd ndk_a;
-    
+
     //
     // Functions
     //
 
     // Constructor
-    keyATMbase(List model_, const int iter_) :
-      keyATMmeta(model_, iter_) {};
+    keyATMbase(List model_) :
+      keyATMmeta(model_) {};
 
-    // Read data
-    void read_data_specific();
+    // Initialize
+    virtual void initialize_specific() override final;
 
-    // Initialization
-    void initialize_specific();
+    // Resume
+    virtual void resume_initialize_specific() override final;
 
     // Iteration
-    virtual void iteration_single(int it);
-    void sample_parameters(int it);
+    virtual void iteration_single(int it) override;
+    virtual void sample_parameters(int it) override final;
     void sample_alpha();
     double alpha_loglik(int k);
-    virtual double loglik_total();
-    double loglik_total_label();
+    virtual double loglik_total() override;
 };
 
 
 #endif
-
