@@ -1,5 +1,6 @@
 #ifndef __keyATM_covPG__INCLUDED__
 #define __keyATM_covPG__INCLUDED__
+#define EIGEN_PERMANENTLY_DISABLE_STUPID_WARNINGS
 
 #include <Rcpp.h>
 #include <RcppEigen.h>
@@ -14,7 +15,7 @@ using namespace std;
 
 class keyATMcovPG : virtual public keyATMmeta
 {
-  public:  
+  public:
     //
     // Parameters
     //
@@ -25,26 +26,24 @@ class keyATMcovPG : virtual public keyATMmeta
     // During the sampling
       std::vector<int> topic_ids;
       std::vector<int> cov_ids;
-    
+
     // Constructor
-    keyATMcovPG(List model_, const int iter_) :
-      keyATMmeta(model_, iter_) {};
+    keyATMcovPG(List model_) :
+      keyATMmeta(model_) {};
 
     // Read data
-    void read_data_specific() final;
+    void read_data_specific() override final;
 
     // Initialization
-    void initialize_specific() final;
+    void initialize_specific() override final;
 
     // Iteration
-    virtual void iteration_single(int it);
-    void sample_parameters(int it);
+    virtual void iteration_single(int it) override final;
+    virtual void sample_parameters(int it) override final;
     void sample_PG(int it);
-    int sample_z_PG(int z, int s, int w, int doc_id); 
-    virtual double loglik_total();
+    int sample_z_PG(int z, int s, int w, int doc_id);
+    virtual double loglik_total() override final;
 };
 
 
 #endif
-
-
